package com.yiqi.core.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.core.domain.ClothTexture;

/**
 * 衣服质地Mapper接口
 *
 * @author xiaohei
 * @date 2023-08-20
 */
public interface ClothTextureMapper extends BaseMapper<ClothTexture> {
    /**
     * 查询衣服质地
     *
     * @param id 衣服质地主键
     * @return 衣服质地
     */
    public ClothTexture selectClothTextureById(Long id);

    /**
     * 查询衣服质地列表
     *
     * @param clothTexture 衣服质地
     * @return 衣服质地集合
     */
    public List<ClothTexture> selectClothTextureList(ClothTexture clothTexture);

    /**
     * 新增衣服质地
     *
     * @param clothTexture 衣服质地
     * @return 结果
     */
    public int insertClothTexture(ClothTexture clothTexture);

    /**
     * 修改衣服质地
     *
     * @param clothTexture 衣服质地
     * @return 结果
     */
    public int updateClothTexture(ClothTexture clothTexture);

    /**
     * 删除衣服质地
     *
     * @param id 衣服质地主键
     * @return 结果
     */
    public int deleteClothTextureById(Long id);

    /**
     * 批量删除衣服质地
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteClothTextureByIds(Long[] ids);
}
